==> automated_testing_framework_plugin_connectivity-1.0.1.tar.gz: lib/src/test_connectivity_helper.dart <==
import 'package:automated_testing_framework/automated_testing_framework.dart';
import 'package:automated_testing_framework_plugin_connectivity/automated_testing_framework_plugin_connectivity.dart';

class TestConnectivityHelper {
  /// Registers the test steps to the optional [registry].  If not set, the
  /// default [TestStepRegistry] will be used.
  static void registerTestSteps([TestStepRegistry registry]) {
    (registry ?? TestStepRegistry.instance).registerCustomSteps([
      TestStepBuilder(
        availableTestStep: AvailableTestStep(
          form: AssertConnectivityForm(),
          help: TestConnectivityTranslations
              .atf_connectivity_help_assert_connectivity,
          id: 'assert_connectivity',
          keys: const {'connected'},
          quickAddValues: {'connected': 'false'},
          title: TestConnectivityTranslations
              .atf_connectivity_title_assert_connectivity,
          widgetless: true,
          type: null,
        ),
        testRunnerStepBuilder: AssertConnectivityStep.fromDynamic,
      ),
      TestStepBuilder(
        availableTestStep: AvailableTestStep(
          form: ResetConnectivityForm(),
          help: TestConnectivityTranslations
              .atf_connectivity_help_reset_connectivity,
          id: 'reset_connectivity',
          keys: const {},
          quickAddValues: const {},
          title: TestConnectivityTranslations
              .atf_connectivity_title_reset_connectivity,
          widgetless: true,
          type: null,
        ),
        testRunnerStepBuilder: ResetConnectivityStep.fromDynamic,
      ),
      TestStepBuilder(
        availableTestStep: AvailableTestStep(
          form: SetConnectivityForm(),
          help: TestConnectivityTranslations
              .atf_connectivity_help_set_connectivity,
          id: 'set_connectivity',
          keys: const {'connected'},
          quickAddValues: null,
          title: TestConnectivityTranslations
              .atf_connectivity_title_set_connectivity,
          widgetless: true,
          type: null,
        ),
        testRunnerStepBuilder: SetConnectivityStep.fromDynamic,
      ),
    ]);
  }
}

==> automated_testing_framework_plugin_connectivity-3.0.0.tar.gz: lib/src/test_connectivity_helper.dart <==
import 'package:automated_testing_framework/automated_testing_framework.dart';
import 'package:automated_testing_framework_plugin_connectivity/automated_testing_framework_plugin_connectivity.dart';

class TestConnectivityHelper {
  /// Registers the test steps to the optional [registry].  If not set, the
  /// default [TestStepRegistry] will be used.
  static void registerTestSteps([TestStepRegistry? registry]) {
    (registry ?? TestStepRegistry.instance).registerCustomSteps([
      TestStepBuilder(
        availableTestStep: AvailableTestStep(
          form: AssertConnectivityForm(),
          help: TestConnectivityTranslations
              .atf_connectivity_help_assert_connectivity,
          id: 'assert_connectivity',
          keys: const {'connected'},
          quickAddValues: {'connected': 'false'},
          title: TestConnectivityTranslations
              .atf_connectivity_title_assert_connectivity,
          widgetless: true,
          type: null,
        ),
        testRunnerStepBuilder: AssertConnectivityStep.fromDynamic,
      ),
      TestStepBuilder(
        availableTestStep: AvailableTestStep(
          form: ResetConnectivityForm(),
          help: TestConnectivityTranslations
              .atf_connectivity_help_reset_connectivity,
          id: 'reset_connectivity',
          keys: const {},
          quickAddValues: const {},
          title: TestConnectivityTranslations
              .atf_connectivity_title_reset_connectivity,
          widgetless: true,
          type: null,
        ),
        testRunnerStepBuilder: ResetConnectivityStep.fromDynamic,
      ),
      TestStepBuilder(
        availableTestStep: AvailableTestStep(
          form: SetConnectivityForm(),
          help: TestConnectivityTranslations
              .atf_connectivity_help_set_connectivity,
          id: 'set_connectivity',
          keys: const {'connected'},
          quickAddValues: null,
          title: TestConnectivityTranslations
              .atf_connectivity_title_set_connectivity,
          widgetless: true,
          type: null,
        ),
        testRunnerStepBuilder: SetConnectivityStep.fromDynamic,
      ),
    ]);
  }
}
